@@ -115,8 +115,13 @@ QStringList SKGFilePlugin::processArguments(const QStringList& iArgument)
     int openMode = 1;  // 0=no open, 1=open last opened if settings set, 2=new document
     if (nbArg != 0) {
         openMode = 2;
-        const QString& filename = iArgument.at(nbArg - 1);
+        QString filename = iArgument.at(nbArg - 1);
         QString extension = QFileInfo(filename).suffix().toUpper();
+        auto inputFile = QFileInfo(filename);
+        if (!inputFile.isAbsolute()) {
+            filename = QFileInfo(QDir::currentPath(), filename).absoluteFilePath();
+        }
+
         QString extensionDocument = m_currentDocument->getFileExtension().toUpper();
         if (QFile(filename).exists() && extension == extensionDocument) {
             if (SKGMainPanel::getMainPanel() != nullptr) {
