@@ -21,23 +21,23 @@
  */
 #include "skgimportpluginbackend.h"
 
+#include <qapplication.h>
+#include <qdir.h>
+#include <qdiriterator.h>
 #include <qfile.h>
 #include <qfileinfo.h>
-#include <qdir.h>
 #include <qprocess.h>
-#include <qapplication.h>
 #include <qstandardpaths.h>
-#include <qdiriterator.h>
 #include <qtconcurrentmap.h>
 
-#include <klocalizedstring.h>
 #include <kaboutdata.h>
+#include <klocalizedstring.h>
 #include <kpluginfactory.h>
 
-#include "skgtraces.h"
-#include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 /**
  * This plugin factory.
@@ -85,16 +85,16 @@ QString SKGImportPluginBackend::getParameter(const QString& iAttribute)
 bool SKGImportPluginBackend::isImportPossible()
 {
     SKGTRACEINFUNC(10);
-    return (!m_importer ? true : getService().data() != nullptr);
+    return (m_importer == nullptr ? true : getService().data() != nullptr);
 }
 
 struct download {
-    download(int iNbToDownload, const QString& iDate, const QString& iCmd, const QString& iPwd, const QString& iPath)
-        : m_nbToDownload(iNbToDownload), m_date(iDate), m_cmd(iCmd), m_pwd(iPwd), m_path(iPath)
+    download(int iNbToDownload, QString  iDate, QString  iCmd, QString  iPwd, QString  iPath)
+        : m_nbToDownload(iNbToDownload), m_date(std::move(iDate)), m_cmd(std::move(iCmd)), m_pwd(std::move(iPwd)), m_path(std::move(iPath))
     {
     }
 
-    typedef QString result_type;
+    using result_type = QString;
 
     QString operator()(const QString& iAccountId)
     {
@@ -115,9 +115,9 @@ struct download {
             if (p.waitForFinished(1000 * 60 * 2)) {
                 if (p.exitCode() == 0) {
                     return iAccountId;
-                } else {
-                    SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed with code %2 (Retry %3)", cmd, p.exitCode(), retry + 1) << endl;
                 }
+                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed with code %2 (Retry %3)", cmd, p.exitCode(), retry + 1) << endl;
+
             } else {
                 SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed due to a time out (Retry %2)", cmd, retry + 1) << endl;
                 p.terminate();
@@ -141,7 +141,7 @@ struct download {
 
 SKGError SKGImportPluginBackend::importFile()
 {
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
@@ -294,7 +294,7 @@ SKGError SKGImportPluginBackend::importFile()
             IFOK(err) {
                 bool checkOK = true;
                 int nb = listDownloadedId.count();
-                if (errors.count()) {
+                if (errors.count() != 0) {
                     // Some accounts have not been downloaded
                     if (nb == 0) {
                         err = SKGError(ERR_FAIL, i18nc("Error message", "No accounts downloaded with the following command:\n%1\nCheck your backend installation.", cmddownload));
@@ -308,7 +308,7 @@ SKGError SKGImportPluginBackend::importFile()
 
                 // import
                 IFOKDO(err, m_importer->getDocument()->stepForward(2, i18nc("Progress message", "Import")))
-                if (!err && nb) {
+                if (!err && (nb != 0)) {
                     // import
                     SKGBEGINPROGRESSTRANSACTION(*m_importer->getDocument(), "#INTERNAL#" % i18nc("Noun, name of the user action", "Import one account with %1", "Backend"), err, nb);
 
