@@ -42,26 +42,26 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGImportPluginJson();
+    ~SKGImportPluginJson() override;
 
     /**
      * To know if export is possible with this plugin
      * @return true or false
      */
-    virtual bool isExportPossible() override;
+    bool isExportPossible() override;
 
     /**
      * Export a file
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError exportFile() override;
+    SKGError exportFile() override;
 
     /**
      * Return the mime type filter
      * @return the mime type filter. Example: "*.csv|CSV file"
      */
-    virtual QString getMimeTypeFilter() const override;
+    QString getMimeTypeFilter() const override;
 
 
 private:
