@@ -21,21 +21,21 @@
  */
 #include "skgscheduledplugin.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kactioncollection.h>
 #include <kpluginfactory.h>
+#include <kstandardaction.h>
 #include <qstandardpaths.h>
 
-#include "skgscheduledpluginwidget.h"
-#include "skgscheduled_settings.h"
-#include "skgrecurrentoperationobject.h"
-#include "skgtraces.h"
-#include "skgmainpanel.h"
-#include "skgtransactionmng.h"
 #include "skgdocumentbank.h"
-#include "skgsuboperationobject.h"
 #include "skghtmlboardwidget.h"
+#include "skgmainpanel.h"
+#include "skgrecurrentoperationobject.h"
+#include "skgscheduled_settings.h"
+#include "skgscheduledpluginwidget.h"
+#include "skgsuboperationobject.h"
+#include "skgtraces.h"
+#include "skgtransactionmng.h"
 
 /**
  * This plugin factory.
@@ -79,7 +79,7 @@ void SKGScheduledPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
     // Automatic insert
-    if (m_currentBankDocument && m_currentBankDocument->getMainDatabase() != nullptr) {
+    if ((m_currentBankDocument != nullptr) && m_currentBankDocument->getMainDatabase() != nullptr) {
         QString doc_id = m_currentBankDocument->getUniqueIdentifier();
         if (m_docUniqueIdentifier != doc_id && m_currentBankDocument->getParameter(QStringLiteral("SKG_DB_BANK_VERSION")) >= QStringLiteral("0.5")) {
             m_docUniqueIdentifier = doc_id;
@@ -183,13 +183,13 @@ bool SKGScheduledPlugin::isInPagesChooser() const
 SKGError SKGScheduledPlugin::savePreferences() const
 {
     SKGError err;
-    if (m_currentBankDocument) {
+    if (m_currentBankDocument != nullptr) {
         // Read Setting
         if (skgscheduled_settings::create_template()) {
             SKGObjectBase::SKGListSKGObjectBase recurrents;
             err = m_currentBankDocument->getObjects(QStringLiteral("v_recurrentoperation"), QStringLiteral("(select count(1) from operation where operation.id=rd_operation_id and t_template='N')=1"), recurrents);
             int nb = recurrents.count();
-            if (nb) {
+            if (nb != 0) {
                 SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Conversion schedule"), err, nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     // Migration of existing schedule in template mode
@@ -262,10 +262,10 @@ void SKGScheduledPlugin::onScheduleOperation()
     SKGTRACEINFUNCRC(10, err);
 
     // Get Selection
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
-        if (nb && m_currentBankDocument) {
+        if ((nb != 0) && (m_currentBankDocument != nullptr)) {
             QStringList list;
             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Operation schedule"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
@@ -311,10 +311,10 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
         SKGAdvice::SKGAdviceActionList autoCorrections;
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
-            QStringList line = result.at(i);
+            const QStringList& line = result.at(i);
             int idRecu = SKGServices::stringToInt(line.at(0));
-            QString idOper = line.at(1);
-            QString amountLastOperation = line.at(3);
+            const QString& idOper = line.at(1);
+            const QString& amountLastOperation = line.at(3);
 
             SKGRecurrentOperationObject recu(m_currentBankDocument, idRecu);
             QString name = recu.getDisplayName();
@@ -349,10 +349,10 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
         SKGAdvice::SKGAdviceActionList autoCorrections;
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
-            QStringList line = result.at(i);
+            const QStringList& line = result.at(i);
             int idRecu = SKGServices::stringToInt(line.at(0));
-            QString currentDate = line.at(1);
-            QString newDate = line.at(2);
+            const QString& currentDate = line.at(1);
+            const QString& newDate = line.at(2);
             if (SKGServices::stringToTime(newDate).date() > QDate::currentDate() && SKGServices::stringToTime(newDate).date() != SKGServices::stringToTime(currentDate).date()) {
                 SKGRecurrentOperationObject recu(m_currentBankDocument, idRecu);
                 QString name = recu.getDisplayName();
@@ -391,9 +391,9 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
         autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
-            QStringList line = result.at(i);
-            QString id = line.at(0);
-            QString name = line.at(1);
+            const QStringList& line = result.at(i);
+            const QString& id = line.at(0);
+            const QString& name = line.at(1);
 
             SKGAdvice ad;
             ad.setUUID("skgscheduledplugin_possibleschedule|" % id);
@@ -419,7 +419,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     SKGError err;
-    if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_notuptodate|"))) {
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_notuptodate|"))) {
         // Get parameters
         QString parameters = iAdviceIdentifier.right(iAdviceIdentifier.length() - 31);
         int pos = parameters.indexOf(';');
@@ -460,7 +460,8 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
         SKGMainPanel::displayErrorMessage(err);
 
         return err;
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_newdate|"))) {
+    }
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_newdate|"))) {
         // Get parameters
         QString parameters = iAdviceIdentifier.right(iAdviceIdentifier.length() - 27);
         int pos = parameters.indexOf(';');
@@ -488,7 +489,8 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
         SKGMainPanel::displayErrorMessage(err);
 
         return err;
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_possibleschedule|"))) {
+    }
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_possibleschedule|"))) {
         // Get parameters
         int idOper = SKGServices::stringToInt(iAdviceIdentifier.right(iAdviceIdentifier.length() - 36));
 
