@@ -21,9 +21,9 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "ui_skgunitpluginwidget_base.h"
 #include "skgtabpage.h"
 #include "skgunitobject.h"
+#include "ui_skgunitpluginwidget_base.h"
 
 class SKGDocumentBank;
 
@@ -144,7 +144,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGUnitPluginWidget)
 
-    Ui::skgunitplugin_base ui;
+    Ui::skgunitplugin_base ui{};
     QTimer m_timer;
 
     QAction* m_upload;
