@@ -40,7 +40,7 @@ tempDir='/data'
 
 class Releasor(object):
     def __init__(self, args):
-        self.ubuntuVersions=['xenial', 'bionic', 'cuttlefish']
+        self.ubuntuVersions=['bionic', 'cosmic']
         self.workdingDir=os.path.join(tempDir, 'skrooge-release_' + args.version)
         print("# Working directory :" + self.workdingDir)    
         if args.version.endswith(".0") or args.stable:
@@ -279,7 +279,7 @@ class Releasor(object):
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
         if rc == 0:
             for line in fileinput.input(['pkg2appimage'], inplace=True):
-                print(line.replace('trusty', 'xenial'), end='')
+                print(line.replace('trusty', 'cosmic'), end='')
                 
             os.chmod('./pkg2appimage', 0o775)
                 
