@@ -23,32 +23,32 @@
 
 #include <math.h>
 
-#include <klocalizedstring.h>
 #include <kconfiggroup.h>
+#include <klocalizedstring.h>
 
 #include <qapplication.h>
-#include <qdir.h>
-#include <qmimedata.h>
-#include <qfont.h>
 #include <qcolor.h>
+#include <qdir.h>
+#include <qfont.h>
 #include <qicon.h>
+#include <qmimedata.h>
 #include <qstandardpaths.h>
 
-#include "skgdocumentbank.h"
 #include "skgaccountobject.h"
+#include "skgbudgetobject.h"
+#include "skgbudgetruleobject.h"
 #include "skgcategoryobject.h"
-#include "skgpayeeobject.h"
+#include "skgdocumentbank.h"
+#include "skgmainpanel.h"
 #include "skgoperationobject.h"
-#include "skgtrackerobject.h"
+#include "skgpayeeobject.h"
 #include "skgrecurrentoperationobject.h"
+#include "skgsuboperationobject.h"
+#include "skgtraces.h"
+#include "skgtrackerobject.h"
+#include "skgtransactionmng.h"
 #include "skgunitobject.h"
 #include "skgunitvalueobject.h"
-#include "skgbudgetruleobject.h"
-#include "skgbudgetobject.h"
-#include "skgsuboperationobject.h"
-#include "skgtransactionmng.h"
-#include "skgtraces.h"
-#include "skgmainpanel.h"
 
 SKGObjectModel::
 SKGObjectModel(SKGDocumentBank* iDocument,
@@ -266,70 +266,81 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
             if (iRole == Qt::UserRole) {
                 if (val != QStringLiteral("0")) {
                     return QLatin1String("Y");
-                } else if (obj->getAttribute(QStringLiteral("r_recurrentoperation_id")) != QStringLiteral("0")) {
+                }
+                if (obj->getAttribute(QStringLiteral("r_recurrentoperation_id")) != QStringLiteral("0")) {
                     return QLatin1String("Y");
                 }
                 return QLatin1String("N");
-            } else {
-                return "";
             }
-        } else if (att == QStringLiteral("t_bookmarked") ||
-                   att == QStringLiteral("t_status") ||
-                   att == QStringLiteral("t_imported") ||
-                   att == QStringLiteral("t_close") ||
-                   att == QStringLiteral("t_action_type")
-                  ) {
+            return "";
+        }
+        if (att == QStringLiteral("t_bookmarked") ||
+            att == QStringLiteral("t_status") ||
+            att == QStringLiteral("t_imported") ||
+            att == QStringLiteral("t_close") ||
+            att == QStringLiteral("t_action_type")
+           ) {
             if (iRole == Qt::UserRole) {
                 if (m_ruleTable && att == QStringLiteral("t_action_type")) {
                     if (val == QStringLiteral("S")) {
                         return i18nc("Noun, a search", "Search");
-                    } else if (val == QStringLiteral("U")) {
-                        return i18nc("Noun, a modification", "Update");
-                    } else {
-                        return i18nc("Noun, an alarm", "Alarm");
                     }
+                    if (val == QStringLiteral("U")) {
+                        return i18nc("Noun, a modification", "Update");
+                    }
+                    return i18nc("Noun, an alarm", "Alarm");
                 }
                 return val;
-            } else {
-                return "";
             }
-        } else if (m_interestTable && att == QStringLiteral("t_expenditure_value_date_mode")) {
+            return "";
+        }
+        if (m_interestTable && att == QStringLiteral("t_expenditure_value_date_mode")) {
             if (val == QStringLiteral("0")) {
                 return i18nc("Noun", "Day -0");
-            } else if (val == QStringLiteral("1")) {
-                return i18nc("Noun", "Day -1");
-            } else if (val == QStringLiteral("2")) {
-                return i18nc("Noun", "Day -2");
-            } else if (val == QStringLiteral("3")) {
-                return i18nc("Noun", "Day -3");
-            } else if (val == QStringLiteral("4")) {
-                return i18nc("Noun", "Day -4");
-            } else if (val == QStringLiteral("5")) {
-                return i18nc("Noun", "Day -5");
-            } else {
-                return i18nc("Noun", "Fifteen");
             }
-        } else if (m_accountTable && att == QStringLiteral("d_reconciliationdate")) {
+            if (val == QStringLiteral("1")) {
+                return i18nc("Noun", "Day -1");
+            }
+            if (val == QStringLiteral("2")) {
+                return i18nc("Noun", "Day -2");
+            }
+            if (val == QStringLiteral("3")) {
+                return i18nc("Noun", "Day -3");
+            }
+            if (val == QStringLiteral("4")) {
+                return i18nc("Noun", "Day -4");
+            }
+            if (val == QStringLiteral("5")) {
+                return i18nc("Noun", "Day -5");
+            }
+            return i18nc("Noun", "Fifteen");
+        }
+        if (m_accountTable && att == QStringLiteral("d_reconciliationdate")) {
             if (val.isEmpty() && iRole == Qt::DisplayRole) {
                 return i18nc("Noun", "Never");
             }
         } else if (m_interestTable && att == QStringLiteral("t_income_value_date_mode")) {
             if (val == QStringLiteral("0")) {
                 return i18nc("Noun", "Day +0");
-            } else if (val == QStringLiteral("1")) {
-                return i18nc("Noun", "Day +1");
-            } else if (val == QStringLiteral("2")) {
-                return i18nc("Noun", "Day +2");
-            } else if (val == QStringLiteral("3")) {
-                return i18nc("Noun", "Day +3");
-            } else if (val == QStringLiteral("4")) {
-                return i18nc("Noun", "Day +4");
-            } else if (val == QStringLiteral("5")) {
-                return i18nc("Noun", "Day +5");
-            } else {
-                return i18nc("Noun", "Fifteen");
             }
-        } else if (getAttributeType(iIndex.column()) == SKGServices::FLOAT) {
+            if (val == QStringLiteral("1")) {
+                return i18nc("Noun", "Day +1");
+            }
+            if (val == QStringLiteral("2")) {
+                return i18nc("Noun", "Day +2");
+            }
+            if (val == QStringLiteral("3")) {
+                return i18nc("Noun", "Day +3");
+            }
+            if (val == QStringLiteral("4")) {
+                return i18nc("Noun", "Day +4");
+            }
+            if (val == QStringLiteral("5")) {
+                return i18nc("Noun", "Day +5");
+            }
+            return i18nc("Noun", "Fifteen");
+        }
+        if (getAttributeType(iIndex.column()) == SKGServices::FLOAT) {
             double dval = SKGServices::stringToDouble(val);
             if (iRole == Qt::DisplayRole) {
                 if (val.isEmpty()) {
@@ -349,7 +360,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 unit.Symbol = QLatin1String("");
                 unit.NbDecimal = 2;
                 if (!att.contains(QStringLiteral("QUANTITY")) && !att.contains(QStringLiteral("f_BALANCE_ENTERED"))) {
-                    unit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                    unit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     if (m_unitvalueTable && !m_cacheUnit.Symbol.isEmpty()) {
                         unit = m_cacheUnit;
                     }
@@ -384,10 +395,10 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 }
 
                 return SKGServices::toCurrencyString(dval, unit.Symbol, unit.NbDecimal);
-            } else {
-                return dval;
             }
-        } else if (getAttributeType(iIndex.column()) == SKGServices::INTEGER) {
+            return dval;
+        }
+        if (getAttributeType(iIndex.column()) == SKGServices::INTEGER) {
             if (m_recurrentoperationTable && att == QStringLiteral("i_nb_times")) {
                 QString t_times = obj->getAttribute(QStringLiteral("t_times"));
                 if (t_times != QStringLiteral("Y")) {
@@ -398,14 +409,16 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
             }
 
             return SKGServices::stringToInt(val);
-        } else if (m_suboperationTable && att.startsWith(QLatin1String("p_"))) {
+        }
+        if (m_suboperationTable && att.startsWith(QLatin1String("p_"))) {
             val = obj->getProperty(att.right(att.count() - 2));
             if (val.isEmpty()) {
                 val = obj->getDocument()->getParameter(att.right(att.count() - 2), obj->getAttribute(QStringLiteral("i_OPID")) % "-operation");
             }
             return val;
-        } else if (m_payeeTable && att == QStringLiteral("t_CATEGORY") && val.isEmpty()) {
-            auto c = static_cast<SKGDocumentBank*>(getDocument())->getCategoryForPayee(obj->getAttribute(QStringLiteral("t_name")));
+        }
+        if (m_payeeTable && att == QStringLiteral("t_CATEGORY") && val.isEmpty()) {
+            auto c = qobject_cast<SKGDocumentBank*>(getDocument())->getCategoryForPayee(obj->getAttribute(QStringLiteral("t_name")));
             if (!c.isEmpty()) {
                 return i18n("Auto: %1", c);
             }
@@ -434,14 +447,16 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
             } else if (att == QStringLiteral("i_NBRECURRENT") && m_operationTable) {
                 if (obj->getAttribute(QStringLiteral("i_NBRECURRENT")) != QStringLiteral("0")) {
                     return m_iconRecurrentMaster;
-                } else if (obj->getAttribute(QStringLiteral("r_recurrentoperation_id")) != QStringLiteral("0")) {
+                }
+                if (obj->getAttribute(QStringLiteral("r_recurrentoperation_id")) != QStringLiteral("0")) {
                     return m_iconRecurrent;
                 }
             } else if (att == QStringLiteral("t_imported")) {
                 QString impStatus = obj->getAttribute(QStringLiteral("t_imported"));
                 if (impStatus == QStringLiteral("Y")) {
                     return m_iconImported;
-                } else if (impStatus == QStringLiteral("P")) {
+                }
+                if (impStatus == QStringLiteral("P")) {
                     return m_iconImportedChecked;
                 }
             } else if (att == QStringLiteral("t_REFUND") || att == QStringLiteral("t_REALREFUND")) {
@@ -462,13 +477,14 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 QString val = obj->getAttribute(att);
                 if (val == QStringLiteral("S")) {
                     return m_iconSearch;
-                } else if (val == QStringLiteral("U")) {
-                    return m_iconUpdate;
-                } else if (val == QStringLiteral("T")) {
-                    return m_iconTemplate;
-                } else {
-                    return m_iconAlarm;
                 }
+                if (val == QStringLiteral("U")) {
+                    return m_iconUpdate;
+                }
+                if (val == QStringLiteral("T")) {
+                    return m_iconTemplate;
+                }
+                return m_iconAlarm;
             }
         } else if (m_unitTable) {
             if (att == QStringLiteral("f_CURRENTAMOUNT")) {
@@ -477,11 +493,14 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 double annualchange = 100.0 * (unit.getAmount() - amountOneYearBefore) / amountOneYearBefore;
                 if (annualchange >= 15) {
                     return m_iconMuchMore;
-                } else if (annualchange <= -15) {
+                }
+                if (annualchange <= -15) {
                     return m_iconMuchLess;
-                } else if (annualchange >= 5) {
+                }
+                if (annualchange >= 5) {
                     return m_iconMore;
-                } else if (annualchange <= -5) {
+                }
+                if (annualchange <= -5) {
                     return m_iconLess;
                 }
             }
@@ -524,7 +543,8 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 QString t_TYPEEXPENSE = obj->getAttribute(QStringLiteral("t_TYPEEXPENSE"));
                 if (t_TYPEEXPENSE == QStringLiteral("-")) {
                     return m_iconCategoryMoins;
-                } else if (t_TYPEEXPENSE == QStringLiteral("+")) {
+                }
+                if (t_TYPEEXPENSE == QStringLiteral("+")) {
                     return m_iconCategoryPlus;
                 }
                 return m_iconCategory;
@@ -534,16 +554,15 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 double val = SKGServices::stringToDouble(obj->getAttribute(att));
                 if (val < -EPSILON) {
                     return m_iconRed;
-                } else if (val > EPSILON) {
-                    return m_iconGreen;
-                } else {
-                    double transferred = SKGServices::stringToDouble(obj->getAttribute(QStringLiteral("f_transferred")));
-                    if (transferred < -EPSILON) {
-                        return m_iconAnber;
-                    } else {
-                        return m_iconGreen;
-                    }
                 }
+                if (val > EPSILON) {
+                    return m_iconGreen;
+                }
+                double transferred = SKGServices::stringToDouble(obj->getAttribute(QStringLiteral("f_transferred")));
+                if (transferred < -EPSILON) {
+                    return m_iconAnber;
+                }
+                return m_iconGreen;
             }
         }
         break;
@@ -554,16 +573,19 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
         if (m_recurrentoperationTable) {
             if (obj->getAttribute(QStringLiteral("i_nb_times")) == QStringLiteral("0")) {
                 return  m_fontDisabledScheduleColor;
-            } else if (att == QStringLiteral("d_date") && SKGServices::stringToTime(obj->getAttribute(QStringLiteral("d_date"))).date() <= QDate::currentDate()) {
+            }
+            if (att == QStringLiteral("d_date") && SKGServices::stringToTime(obj->getAttribute(QStringLiteral("d_date"))).date() <= QDate::currentDate()) {
                 return m_fontNegativeColor;
             }
         } else if (m_operationTable) {
             if (SKGServices::stringToTime(obj->getAttribute(QStringLiteral("d_date"))).date() > QDate::currentDate()) {
                 return m_fontFutureOperationsColor;
-            } else if (getAttributeType(iIndex.column()) != SKGServices::FLOAT) {
+            }
+            if (getAttributeType(iIndex.column()) != SKGServices::FLOAT) {
                 if (obj->getAttribute(QStringLiteral("t_imported")) == QStringLiteral("P")) {
                     return  m_fontNotValidatedOperationsColor;
-                } else if (m_suboperationTable) {
+                }
+                if (m_suboperationTable) {
                     return m_fontSubOperationsColor;
                 }
             }
@@ -587,75 +609,76 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
         if (m_operationTable && att == QStringLiteral("t_status")) {
             QString cond = obj->getAttribute(QStringLiteral("t_status"));
             if (cond == QStringLiteral("P")) {
-                return int(Qt::PartiallyChecked);
-            } else if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else if (cond == QStringLiteral("N")) {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::PartiallyChecked);
+            }
+            if (cond == QStringLiteral("Y")) {
+                return static_cast<int>(Qt::Checked);
+            }
+            if (cond == QStringLiteral("N")) {
+                return static_cast<int>(Qt::Unchecked);
             }
         } else if (att == QStringLiteral("t_close")) {
             QString cond = obj->getAttribute(QStringLiteral("t_close"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_recurrentoperationTable && att == QStringLiteral("i_auto_write_days")) {
             QString cond = obj->getAttribute(QStringLiteral("t_auto_write"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_recurrentoperationTable && att == QStringLiteral("i_warn_days")) {
             QString cond = obj->getAttribute(QStringLiteral("t_warn"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_recurrentoperationTable && att == QStringLiteral("i_nb_times")) {
             QString cond = obj->getAttribute(QStringLiteral("t_times"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_budgetRuleTable && att == QStringLiteral("t_CATEGORYCONDITION")) {
             QString cond = obj->getAttribute(QStringLiteral("t_category_condition"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_budgetRuleTable && att == QStringLiteral("i_year")) {
             QString cond = obj->getAttribute(QStringLiteral("t_year_condition"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_budgetRuleTable && att == QStringLiteral("i_month")) {
             QString cond = obj->getAttribute(QStringLiteral("t_month_condition"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_budgetRuleTable && att == QStringLiteral("t_CATEGORY")) {
             QString cond = obj->getAttribute(QStringLiteral("t_category_target"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
+
         } else  if (m_budgetTable && att == QStringLiteral("t_CATEGORY")) {
             QString cond = obj->getAttribute(QStringLiteral("t_including_subcategories"));
             if (cond == QStringLiteral("Y")) {
-                return int(Qt::Checked);
-            } else {
-                return int(Qt::Unchecked);
+                return static_cast<int>(Qt::Checked);
             }
+            return static_cast<int>(Qt::Unchecked);
         }
         break;
     }
@@ -666,11 +689,11 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
         if (getAttributeType(iIndex.column()) == SKGServices::FLOAT) {
             // Add secondary unit
             if (!att.contains(QStringLiteral("QUANTITY")) && att != QStringLiteral("f_coef") && att != QStringLiteral("f_rate")) {
-                SKGServices::SKGUnitInfo secondaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
+                SKGServices::SKGUnitInfo secondaryUnit = qobject_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
                 if (!secondaryUnit.Symbol.isEmpty()) {
                     double val = SKGServices::stringToDouble(obj->getAttribute(att));
                     if ((!att.endsWith(QLatin1String("_INCOME")) && !att.endsWith(QLatin1String("_EXPENSE"))) || val != 0) {
-                        if (secondaryUnit.Value) {
+                        if (secondaryUnit.Value != 0.0) {
                             toolTipString = SKGServices::toCurrencyString(val / secondaryUnit.Value, secondaryUnit.Symbol, secondaryUnit.NbDecimal);
                         }
                     }
@@ -681,7 +704,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
             if (m_operationTable && !m_suboperationTable) {
                 SKGOperationObject op(*obj);
                 if (!op.isTemplate()) {
-                    SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                    SKGServices::SKGUnitInfo primaryUnit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
 
                     // Add original amount
                     QString originalAmount = obj->getProperty(QStringLiteral("SKG_OP_ORIGINAL_AMOUNT"));
@@ -742,7 +765,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                         toolTipString += QStringLiteral("\n\n");
                     }
 
-                    SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                    SKGServices::SKGUnitInfo primaryUnit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     toolTipString += i18nc("Noun", "Original delta=%1",
                                            SKGServices::toCurrencyString(val, primaryUnit.Symbol, primaryUnit.NbDecimal));
                 } else if (att == QStringLiteral("f_budgeted_modified")) {
@@ -785,7 +808,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                     SKGTrackerObject tracker(getDocument());
                     tracker.setName(trackerName);
                     tracker.load();
-                    SKGServices::SKGUnitInfo unit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                    SKGServices::SKGUnitInfo unit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     toolTipString = SKGServices::toCurrencyString(tracker.getCurrentAmount(), unit.Symbol, unit.NbDecimal);
                 }
             } else if (att == QStringLiteral("t_PAYEE")) {
@@ -802,7 +825,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
 
                     auto c = payee.getAttribute(QStringLiteral("t_CATEGORY"));
                     if (c.isEmpty()) {
-                        c = static_cast<SKGDocumentBank*>(getDocument())->getCategoryForPayee(payeeName, false);
+                        c = qobject_cast<SKGDocumentBank*>(getDocument())->getCategoryForPayee(payeeName, false);
                     }
                     if (!c.isEmpty()) {
                         toolTipString += i18nc("Information", "Category= %1\n", c);
@@ -924,7 +947,7 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
     if (iRole == Qt::CheckStateRole) {
         SKGError err;
         {
-            Qt::CheckState newState = static_cast<Qt::CheckState>(iValue.toInt());
+            auto newState = static_cast<Qt::CheckState>(iValue.toInt());
             if (m_accountTable) {
                 SKGAccountObject obj(getObject(iIndex));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
@@ -955,12 +978,12 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
             } else if (m_operationTable && !m_suboperationTable) {
                 // Get the real object, not the object from the view
                 SKGObjectBase* objtmp = getObjectPointer(iIndex);
-                if (objtmp) {
+                if (objtmp != nullptr) {
                     SKGOperationObject obj = SKGOperationObject(objtmp->getDocument(), objtmp->getID());
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err);
                     SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
                     SKGOperationObject::OperationStatus t_status = statusinitial;
-                    if (QApplication::keyboardModifiers() &Qt::ControlModifier) {
+                    if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u) {
                         // 2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
                         t_status = SKGOperationObject::CHECKED;
                         // t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
@@ -982,7 +1005,7 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
 
                 // Get the real object, not the object from the view
                 SKGObjectBase* objtmp = getObjectPointer(iIndex);
-                if (objtmp) {
+                if (objtmp != nullptr) {
                     SKGRecurrentOperationObject obj = SKGRecurrentOperationObject(objtmp->getDocument(), objtmp->getID());
 
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err);
@@ -1003,7 +1026,7 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
 
                 // Get the real object, not the object from the view
                 SKGObjectBase* objtmp = getObjectPointer(iIndex);
-                if (objtmp) {
+                if (objtmp != nullptr) {
                     SKGBudgetRuleObject obj = SKGBudgetRuleObject(objtmp->getDocument(), objtmp->getID());
 
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err);
@@ -1026,7 +1049,7 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
 
                 // Get the real object, not the object from the view
                 SKGObjectBase* objtmp = getObjectPointer(iIndex);
-                if (objtmp) {
+                if (objtmp != nullptr) {
                     SKGBudgetObject obj = SKGBudgetObject(objtmp->getDocument(), objtmp->getID());
 
                     SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget update"), err);
@@ -1098,11 +1121,11 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
     if (iAction == Qt::IgnoreAction) {
         return true;
     }
-    if (!iData || !(iData->hasFormat(QStringLiteral("application/skg.category.ids")) ||
-                    iData->hasFormat(QStringLiteral("application/skg.payee.ids")) ||
-                    iData->hasFormat(QStringLiteral("application/skg.account.ids")) ||
-                    iData->hasFormat(QStringLiteral("application/skg.refund.ids")) ||
-                    iData->hasFormat(QStringLiteral("application/skg.unit.ids")))) {
+    if ((iData == nullptr) || !(iData->hasFormat(QStringLiteral("application/skg.category.ids")) ||
+                                iData->hasFormat(QStringLiteral("application/skg.payee.ids")) ||
+                                iData->hasFormat(QStringLiteral("application/skg.account.ids")) ||
+                                iData->hasFormat(QStringLiteral("application/skg.refund.ids")) ||
+                                iData->hasFormat(QStringLiteral("application/skg.unit.ids")))) {
         return false;
     }
     if (iColumn > 0) {
@@ -1267,7 +1290,7 @@ void SKGObjectModel::dataModified(const QString& iTableName, int iIdTransaction)
 
 QString SKGObjectModel::formatMoney(double iValue) const
 {
-    return getDocument()->formatMoney(iValue, static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit(), false);
+    return getDocument()->formatMoney(iValue, qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit(), false);
 }
 
 
