@@ -22,10 +22,10 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgobjectbase.h"
 #include "skgaccountobject.h"
-#include "skgerror.h"
 #include "skgbankmodeler_export.h"
+#include "skgerror.h"
+#include "skgobjectbase.h"
 
 class SKGInterestObject;
 
@@ -92,7 +92,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGInterestObject& operator= (const SKGObjectBase& iObject) override;
+    SKGInterestObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
@@ -136,7 +136,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError setDate(const QDate iDate);
+    SKGError setDate(QDate iDate);
 
     /**
      * Get date of this value
