@@ -22,23 +22,23 @@
 #include "skgreport.h"
 
 #include <grantlee/engine.h>
-#include <grantlee/templateloader.h>
-#include <grantlee/qtlocalizer.h>
 #include <grantlee/metatype.h>
+#include <grantlee/qtlocalizer.h>
+#include <grantlee/templateloader.h>
 
 #include <kaboutdata.h>
 #include <kcolorscheme.h>
 
-#include <qfile.h>
 #include <qdir.h>
+#include <qfile.h>
 #include <qfont.h>
+#include <qfontdatabase.h>
 #include <qstandardpaths.h>
 #include <qurl.h>
-#include <qfontdatabase.h>
 
-#include "skgtraces.h"
 #include "skgdocument.h"
 #include "skgobjectbase.h"
+#include "skgtraces.h"
 
 GRANTLEE_BEGIN_LOOKUP(SKGObjectBase)
 Q_UNUSED(object);
@@ -46,7 +46,7 @@ Q_UNUSED(property);
 GRANTLEE_END_LOOKUP
 
 SKGReport::SKGReport(SKGDocument* iDocument)
-    : QObject(), m_document(iDocument), m_previous(nullptr), m_pointSize(10)
+    :  m_document(iDocument), m_previous(nullptr), m_pointSize(10)
 {
     SKGTRACEINFUNC(1);
 
@@ -57,7 +57,7 @@ SKGReport::SKGReport(SKGDocument* iDocument)
 SKGReport::~SKGReport()
 {
     SKGTRACEINFUNC(1);
-    if (m_previous) {
+    if (m_previous != nullptr) {
         delete m_previous;
         m_previous = nullptr;
     }
@@ -67,7 +67,7 @@ void SKGReport::setPeriod(const QString& iPeriod)
 {
     if (iPeriod != m_cache[QStringLiteral("period")]) {
         cleanCache(false);
-        if (m_previous) {
+        if (m_previous != nullptr) {
             delete m_previous;
             m_previous = nullptr;
         }
@@ -108,12 +108,31 @@ SKGReport* SKGReport::getPrevious()
     return m_previous;
 }
 
+void SKGReport::setTipsOfDay(const QStringList& iTipsOfDays)
+{
+    m_tipsOfTheDay = iTipsOfDays;
+
+    emit changed();
+}
+
+QString SKGReport::getTipOfDay() const
+{
+    auto tips = getTipsOfDay();
+    auto tip = tips.count() > 0 ? SKGServices::htmlToString(tips.at(qrand() % tips.size())) : QString();
+    return tip;
+}
+
+QStringList SKGReport::getTipsOfDay() const
+{
+    return m_tipsOfTheDay;
+}
+
 QVariantHash SKGReport::getContextProperty()
 {
     QVariantHash mapping;
     addItemsInMapping(mapping);
 
-    if (m_document) {
+    if (m_document != nullptr) {
         mapping.insert(QStringLiteral("document"), QVariant::fromValue<QObject*>(m_document));
     }
     return mapping;
@@ -155,6 +174,7 @@ void SKGReport::addItemsInMapping(QVariantHash& iMapping)
     iMapping.insert(QStringLiteral("about_homepage"), about.homepage());
     iMapping.insert(QStringLiteral("about_shortdescription"), about.shortDescription());
     iMapping.insert(QStringLiteral("about_othertext"), about.otherText());
+    iMapping.insert(QStringLiteral("about_did_you_know"), i18nc("Title for tips of the day", "Did you know ...?"));
 }
 
 SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFile, QString& oHtml)
@@ -171,11 +191,11 @@ SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFi
     gEngine.addTemplateLoader(gLoader);
 
     Grantlee::Template gTemplate = gEngine.loadByName(QFileInfo(iFile).fileName());
-    if (gTemplate->error()) {
+    if (gTemplate->error() != 0u) {
         err = SKGError(gTemplate->error(), gTemplate->errorString());
     } else {
         QVariantHash mapping;
-        if (iReport) {
+        if (iReport != nullptr) {
             mapping = iReport->getContextProperty();
         }
         Grantlee::Context gContext(mapping);
@@ -186,7 +206,7 @@ SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFi
             oHtml = gTemplate->render(&gContext);
             QRegExp rx(QStringLiteral("\\n\\s*\\n"));
             oHtml = oHtml.replace(rx, QStringLiteral("\n"));
-            if (gTemplate->error()) {
+            if (gTemplate->error() != 0u) {
                 err = SKGError(gTemplate->error(), gTemplate->errorString());
             }
         }
