@@ -302,7 +302,14 @@ qlonglong SKGServices::stringToInt(const QString& iNumber)
 
 QString SKGServices::stringToSqlString(const QString& iString)
 {
-    QString output = iString;
+    QString output;
+
+    for (const auto& c : iString) {
+        if (c.isPrint() || c == QChar('\n')) {
+            output.append(QChar(c));
+        }
+    }
+
     output.replace('\'', QStringLiteral("''"));
     return output;
 }
