@@ -324,6 +324,20 @@ int main(int argc, char** argv)
             SKGTEST(QStringLiteral("QIF:getValue"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("250"));
         }
     }
+
+    {
+        // 400724
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err);
+
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif2/400724.qif"));
+            SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
+        }
+    }
     // End test
     SKGENDTEST();
 }
