@@ -135,7 +135,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("XHB.load"), account.load(), true);
             SKGBankObject bank;
             SKGTESTERROR(QStringLiteral("XHB.load"), account.getBank(bank), true);
-            SKGTEST(QStringLiteral("XHB:getName"), bank.getName(), QString(""));
+            SKGTEST(QStringLiteral("XHB:getName"), bank.getName(), QLatin1String(""));
         }
         {
             SKGAccountObject account(&document1);
