@@ -43,7 +43,7 @@ int main(int argc, char** argv)
         SKGTESTERROR(QStringLiteral("document1.load()"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestpfs/personalfinancescore.skg"), true);
 
         SKGError err;
-        SKGReportBank* rep = static_cast<SKGReportBank*>(document1.getReport());
+        auto* rep = qobject_cast<SKGReportBank*>(document1.getReport());
 
         rep->setPeriod(QStringLiteral("2010"));
         SKGTEST(QStringLiteral("SKGReportBank:getPersonalFinanceScore"), SKGServices::doubleToString(rep->getPersonalFinanceScoreDetails().value(QStringLiteral("value")).toDouble()), QStringLiteral("-0.5238095238"));
