@@ -259,7 +259,7 @@ int main(int argc, char** argv)
         {
             SKGBEGINTRANSACTION(document1, QStringLiteral("PROCESS_1"), err);
             SKGObjectBase::SKGListSKGObjectBase rules;
-            SKGTESTERROR(QStringLiteral("RULE:execute"), document1.getObjects(QStringLiteral("rule"), QString(""), rules), true);
+            SKGTESTERROR(QStringLiteral("RULE:execute"), document1.getObjects(QStringLiteral("rule"), QLatin1String(""), rules), true);
             for (int i = 0; i < rules.count(); ++i) {
                 SKGRuleObject rule(rules.at(i));
                 SKGTESTERROR(QStringLiteral("RULE:execute"), rule.execute(), true);
