@@ -195,7 +195,8 @@ public:
         SKGAccountObject account(&(DOC)); \
         SKGTESTERROR(QStringLiteral(ACCOUNT) % ".setName(QStringLiteral(" % (ACCOUNT) % "))", account.setName(QStringLiteral(ACCOUNT)), true); \
         SKGTESTERROR(QStringLiteral(ACCOUNT) % ".load(QStringLiteral(" % QStringLiteral(ACCOUNT) % "))", account.load(), true); \
-        SKGTEST(QStringLiteral(ACCOUNT) % ".getCurrentAmount(" % QStringLiteral(ACCOUNT) % ")", SKGServices::doubleToString(account.getCurrentAmount()), SKGServices::doubleToString(AMOUNT));\
+        if (qAbs(account.getCurrentAmount()-AMOUNT)>10e-4) {\
+            SKGTEST(QStringLiteral(ACCOUNT) % ".getCurrentAmount(" % QStringLiteral(ACCOUNT) % ")", SKGServices::toCurrencyString(account.getCurrentAmount(), "Euros", 2), SKGServices::toCurrencyString(AMOUNT, "Euros", 2));\
+        }\
     }
-
 #endif
