@@ -20,9 +20,6 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtestmacro.h"
-#if QT_VERSION < 0x050700
-#include <klocale.h>
-#endif
 #include <qsqldatabase.h>
 #include <qthread.h>
 #include <unistd.h>
@@ -50,11 +47,6 @@ int main(int argc, char** argv)
     Q_UNUSED(argc);
     Q_UNUSED(argv);
 
-#if QT_VERSION < 0x050700
-    KLocale::global()->setNegativePrefixCurrencySymbol(false);
-    KLocale::global()->setPositivePrefixCurrencySymbol(false);
-#endif
-
     // Init test
     SKGINITTEST(true);
 
